@@ -3,7 +3,7 @@
     Coinkit
     ~~~~~
     
-    :copyright: (c) 2013 by Halfmoon Labs
+    :copyright: (c) 2014 by Halfmoon Labs
     :license: MIT, see LICENSE for more details.
 """
 
@@ -14,15 +14,9 @@ import binascii
 
 """ Format checking """
 
-from .b58check import is_b58check, b58check_decode
+from characters.hex import is_hex
 
-def is_hex(s):
-    try:
-        int(s, 16)
-    except ValueError:
-        return False
-    else:
-        return True
+from .b58check import is_b58check, b58check_decode
 
 def is_secret_exponent(val, curve_order):
     return (isinstance(val, (int, long)) and val >= 1 and val < curve_order)
